# Py-GSuite-APIs

This package is meant to standardize and simplify working with Google Sheets, Slides, and Drive APIs through utility classes and functions. It also seeks to provide an interactive environment to inspect and valdiate the shape/structure of requests by using Pydantic models that mirror the Classes implemented by Google APIs.

## NOTE:

- This repo is under active development and is not yet intended for production.
- Python >=3.7 required

## Development

Create a new conda environment:

```bash
conda env create -f environment.yml && conda activate pyGsuiteApis
```

And install the appropriate packages:

```bash
python setup.py develop
```

## Upload

Build wheels using `setup.py` and python.

```bash
python3 setup.py sdist bdist_wheel
```

Then upload it with twine.

```bash
python3 -m twine upload --skip-existing dist/*
```
